@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: modinfo.c,v 1.6 1998/01/07 08:34:15 rth Exp $"
+#ident "$Id: modinfo.c,v 1.9 1998/08/02 20:47:54 rth Exp $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -53,6 +53,8 @@ search_module_path(char *base)
     "/lib/modules/%s/ipv4:"
     "/lib/modules/%s/ipv6:"
     "/lib/modules/%s/sound:"
+    "/lib/modules/%s/fc4:"
+    "/lib/modules/%s/video:"
     "/lib/modules/%s/misc:"
     "/lib/modules/default/fs:"
     "/lib/modules/default/net:"
@@ -62,6 +64,8 @@ search_module_path(char *base)
     "/lib/modules/default/ipv4:"
     "/lib/modules/default/ipv6:"
     "/lib/modules/default/sound:"
+    "/lib/modules/default/fc4:"
+    "/lib/modules/default/video:"
     "/lib/modules/default/misc:"
     "/lib/modules/fs:"
     "/lib/modules/net:"
@@ -71,6 +75,8 @@ search_module_path(char *base)
     "/lib/modules/ipv4:"
     "/lib/modules/ipv6:"
     "/lib/modules/sound:"
+    "/lib/modules/fc4:"
+    "/lib/modules/video:"
     "/lib/modules/misc";
 
   char *path, *p, *filename;
@@ -242,7 +248,7 @@ show_parameter(struct obj_file *f, char *key, char *value, char *desc)
 {
   struct obj_symbol *sym;
   int min, max;
-  char *p = key;
+  char *p = value;
   
   sym = obj_find_symbol(f, key);
   if (sym == NULL)
@@ -329,11 +335,11 @@ show_module_parameters(struct obj_file *f)
 	      char *desckey = xmalloc(namelen + 5 + 1);
 
 	      strncpy(pname, ptr + 5, namelen - 5);
-	      pname[namelen+1] = '\0';
+	      pname[namelen - 5] = '\0';
 
 	      strcpy(desckey, "parm_desc_");
 	      strncat(desckey, ptr + 5, namelen - 5);
-	      desckey[namelen + 5 + 1] = '\0';
+	      desckey[namelen + 5] = '\0';
 
 	      show_parameter(f, pname, value+1, get_modinfo_value(f,desckey));
 
@@ -450,7 +456,8 @@ int main(int argc, char *argv[])
 
   error_file = "modinfo";
 
-  show_module_info(argv[optind], fmtstr, do_parameters);
+  while (optind < argc)
+    show_module_info(argv[optind], fmtstr, do_parameters);
 
   return 0;
 }
