@@ -19,6 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#ident "$Id: obj_load.c,v 1.2 1998/01/23 09:33:39 rth Exp $"
 
 #include <alloca.h>
 #include <string.h>
@@ -196,6 +197,12 @@ obj_load (FILE *fp)
 	    strtab = f->sections[sec->header.sh_link]->contents;
 	    sym = (ElfW(Sym) *) sec->contents;
 
+	    /* Allocate space for a table of local symbols.  */
+	    j = f->local_symtab_size = sec->header.sh_info;
+	    f->local_symtab = xmalloc(j *= sizeof(struct obj_symbol *));
+	    memset(f->local_symtab, 0, j);
+
+	    /* Insert all symbols into the hash table.  */
 	    for (j = 1, ++sym; j < nsym; ++j, ++sym)
 	      {
 		const char *name;
@@ -204,8 +211,9 @@ obj_load (FILE *fp)
 		else
 		  name = f->sections[sym->st_shndx]->name;
 
-		obj_add_symbol(f, name, sym->st_info, sym->st_shndx,
+		obj_add_symbol(f, name, j, sym->st_info, sym->st_shndx,
 			       sym->st_value, sym->st_size);
+
 	      }
 	  }
 	break;
